#!/bin/sh
#
# Copyright (c) 2014 IBM Corporation
# All rights reserved.
#

/usr/bin/dialog --title "Welcome" --msgbox "The following set of dialogs will guide you through the License agreement, network setup and password updates." 15 40

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=ibmvmcoc-license
. gettext.sh

case $LANG in
  fr_FR.UTF-8)
      LICENSEFILE="license_fr.txt";;
  es_ES.UTF-8)
      LICENSEFILE="license_es.txt";;
  de_DE.UTF-8)
      LICENSEFILE="license_de.txt";;
  it_IT.UTF-8)
      LICENSEFILE="license_it.txt";;
  pt_BR.UTF-8)
      LICENSEFILE="license_pt_BR.txt";;
  ja_JP.UTF-8)
      LICENSEFILE="license_ja.txt";;
  ko_KR.UTF-8)
      LICENSEFILE="license_ko.txt";;
  zh_CN.UTF-8)
      LICENSEFILE="license_zh.txt";;
  zh_TW.UTF-8)
      LICENSEFILE="license.zh_TW.txt";;
   *)  LICENSEFILE="license.txt";;
esac

LICENSE_PATH=${installRoot}/license/${LICENSEFILE}

# Show place holder until MFQA is installed
if [[ !(-e $LICENSE_PATH) ]]; then
	LICENSE_PATH=/root/setup/sample.txt
fi

# show the license
BACKTITLE="IBM MobileFirst Quality Assurance License Agreement"
/usr/bin/dialog --backtitle "${BACKTITLE}" --exit-label "I understand" --textbox ${LICENSE_PATH} 20 80

BACKTITLE="IBM MobileFirst Quality Assurance NOTICES AND INFORMATION"
/usr/bin/dialog --backtitle "${BACKTITLE}" --exit-label "I understand" --textbox ${installRoot}/license/notices.txt 20 80


/usr/bin/dialog --title "Information" \
	--msgbox "A copy of the license agreement can be found at the following location:\n${installRoot}/license/" 10 40


#################################################
# Set static IP
#################################################

ip=""
netmask=""
gateway=""
dns1=""
dns2=""
dnspath=""
isdhcp="n"
answer="n"


counterForOverride=0
while [ $counterForOverride == 0 ]; do

	counterNetwork=0
	while [ $counterNetwork == 0 ]; do

		if [ -e ~/.setupran ]; then
			/usr/bin/dialog --title "Setup network configuration" --clear \
					--yesno "Would you like to change the network configuration now?" 10 40
			setupNetworkResponse=$?
		else
			setupNetworkResponse=0
			counterNetwork=1
			counterForOverride=1
		fi
		
		case $setupNetworkResponse in
			0)
				setupNetwork="TRUE"

				##################################################
				# Newtork Setup
				##################################################

				counter=0
				while [ $counter == 0 ]; do

					if [ -e ~/.setupran ]; then
							/usr/bin/dialog --title "Setup" --clear \
							--yesno "Would you like to change the hostname?" 10 40
						setupHostName=$?
					else
						setupHostName=0
					fi
				
					case $setupHostName in
						0)
							hostname=`hostname`

							###############################
							# Get input
							############################### 

							/usr/bin/dialog --title "Setup hostname" --clear \
								--inputbox "Enter hostname:" 10 40 "$hostname" 2>tmp
								
							sel=$?
							case $sel in
								0)
									hostname=$(cat tmp)
									sed -i -e 's#^\(HOSTNAME=\).*$#\1'"$hostname"'#' /etc/sysconfig/network
									hostname $hostname

									/usr/bin/dialog --title "Complete Report" --msgbox "Host name has been updated." 10 40
									counter=1;;
								1);;
								255);;
							esac
							rm -f tmp;;
						1)
							counter=1;;
						255)
							counter=1;;
					esac
				done
				
				counterNetworkType=0
				until [ $counterNetworkType != 0 ]; do
		
					/usr/bin/dialog --title "Setup network configuration" --clear \
							--ok-label "DHCP" \
							--extra-button --extra-label "Static" \
							--yesno "Setup network with DHCP or Static?" 10 40

					case $? in
						0)
							isdhcp="y"
							counterNetworkType=1
							counterNetwork=1
							;;
						3)
							#dynamic ip cancel, i.e. go static
							isdhcp="n"
							
							counterStaticIP=0
							until [ $counterStaticIP != 0 ]; do

								dialog --ok-label "Submit" \
									--title "Setup network configuration" \
									--form "Network information" \
									15 70 0 \
									"IP:" 		1 1 "$ip"  	  1 17 50 0 \
									"Netmask:"    	2 1 "$netmask" 	  2 17 50 0 \
									"Gateway:"    	3 1 "$gateway" 	  3 17 50 0 \
									"DNS1:"     	4 1 "$dns1" 	  4 17 50 0 \
									"DNS2:"			5 1 "$dns2"	 	  5 17 50 0 \
									"DNS Search Path:" 6 1 "$dnspath" 6 17 50 0 \
								2>VALUES

								case $? in
									0)
										ip=`awk 'NR==1' VALUES`
										netmask=`awk 'NR==2' VALUES`
										gateway=`awk 'NR==3' VALUES`
										dns1=`awk 'NR==4' VALUES`
										dns2=`awk 'NR==5' VALUES`
										dnspath=`awk 'NR==6' VALUES`
										rm -f VALUES

										dialog --title "Confirm" \
											--yesno "Is the following correct?\n  IP: $ip\n  Netmask: $netmask\n  Gateway: $gateway\n  DNS1: $dns1\n  DNS2: $dns2\n  DNS Search Path: $dnspath\n" 11 70

										case $? in
											0)
												counterStaticIP=1
												counterNetworkType=1
												counterNetwork=1
												;;
											1)
												ip=""
												netmask=""
												gateway=""
												dns1=""
												dns2=""
												dnspath=""
												;;
											255)
												ip=""
												netmask=""
												gateway=""
												dns1=""
												dns2=""
												dnspath=""
												;;
										esac
										;;

									#static ip cancel
									1)
										rm -f VALUES
										counterNetworkType=1
										counterStaticIP=1
										;;
									255)
										rm -f VALUES
										counterStaticIP=1
										;;
								esac
							done
							;;
						*)
							counterNetworkType=1
							;;
					esac
				done
				;;
			1)
				counterNetwork=1
				counterForOverride=1;;
			255)
				counterNetwork=1
				counterForOverride=1;;
		esac
	done


	################################
	# Update ifcfg
	################################
	ethIds=("eth0" "eth1" "eth2" "eth3" "eth4")

	for device in "${ethIds[@]}"
	do
		if test=`ifconfig $device`
		then
			hwaddr=`ifconfig $device | grep -i hwaddr | sed -e 's#^.*hwaddr[[:space:]]*##I'` 
			break
		fi
	done

	ifcfgFile="/etc/sysconfig/network-scripts/ifcfg-$device"

	## Ask to overwrite only if chosen to setup network
	if [ -e $ifcfgFile ] && [ $setupNetwork = "TRUE" ]
	then
		/usr/bin/dialog --title "Override" --yesno "Network setting file already exists, override?" 10 40

		case $? in
			0)
			counterForOverride=1
			rm -rf $ifcfgFile;;
			1);;
			255);;
		esac
	fi

done

ifcfgUpdated=0

if [ ! -e $ifcfgFile ]
then
	echo DEVICE=$device > $ifcfgFile
	echo TYPE=Ethernet >> $ifcfgFile
	echo ONBOOT=yes >> $ifcfgFile
	echo NM_CONTROLLED=yes >> $ifcfgFile
	echo HWADDR=$hwaddr >> $ifcfgFile
	if [ x"$isdhcp" = "xy" ] || [ x"$isdhcp" = "xY" ]
	then
		echo BOOTPROTO=dhcp >> $ifcfgFile
		if [ $hostname != "localhost" ]
		then
			echo DHCP_HOSTNAME=$hostname >> $ifcfgFile
		fi
	else
		echo BOOTPROTO=none >> $ifcfgFile
		echo IPADDR=$ip >> $ifcfgFile
		echo NETMASK=$netmask >> $ifcfgFile
		echo GATEWAY=$gateway >> $ifcfgFile
		
		echo search $dnspath > /etc/resolv.conf
		echo nameserver $dns1 >> /etc/resolv.conf
		echo nameserver $dns2 >> /etc/resolv.conf
	fi

	ifcfgUpdated=1
fi

###################################
# Completed report
###################################

if [ $ifcfgUpdated -eq 1 ] && [ $setupNetwork = "TRUE" ]
then
	if [ x"$isdhcp" = "xy" ] || [ x"$isdhcp" = "xY" ]
	then
		/usr/bin/dialog --title "Complete Report" --msgbox "Device $device has been setup with DHCP." 10 40
	else
		/usr/bin/dialog --title "Complete Report" --msgbox "Device $device has been setup with static ip provided." 10 40
	fi
fi

/usr/bin/dialog --title "Complete Report" --msgbox "For further change please use system-config-network." 10 40 


###################################
# Change password
###################################

counterPassword=0
until [ $counterPassword != 0 ]; do
	dialog --title "Setup" --clear \
			--yesno "Would you like to change root password?" 10 40
	case $? in
		0)

			counterPassword_1=0
			until [ $counterPassword_1 != 0 ]; do

				newPasswd=$(dialog --insecure --passwordbox "Enter new password for root." 10 40 3>&1 1>&2 2>&3)

				case $? in
					0)
						newPasswd2=$(dialog --insecure --passwordbox "Reenter new password for root." 10 40 3>&1 1>&2 2>&3)

						case $? in
							0)
							if [ "$newPasswd" == "$newPasswd2" ]
								then 
									if [ "$newPasswd" == "" ]
									then
										dialog --msgbox "No password was entered.\n\nPlease try it again." 10 40
									else
										echo -e "$newPasswd\n$newPasswd" | passwd root
										counterPassword_1=1
										counterPassword=1
										dialog --msgbox "Password successfully updated for root." 10 40
									fi
										
								else
									dialog --msgbox "Passwords do not match.\n\nPlease try it again." 10 40
								fi
								;;
							1)
								counterPassword_1=1
								;;
							255)
								;;
						esac
						;;

					1)
						counterPassword_1=1;;
					255)
						counterPassword_1=1;;
				esac
			done
			;;
		1)
			dialog --msgbox "Password was not changed for root." 10 40
			counterPassword=1;;
		255)
			dialog --msgbox "Password was not changed for root." 10 40
			counterPassword=1;;
	esac
done


counterPassword=0
until [ $counterPassword != 0 ]; do
	dialog --title "Setup" --clear \
			--yesno "Would you like to change utest password?" 10 40
	case $? in
		0)
			counterPassword_1=0
			until [ $counterPassword_1 != 0 ]; do

				newPasswd=$(dialog --insecure --passwordbox "Enter new password for utest." 10 40 3>&1 1>&2 2>&3)

				case $? in
					0)
						newPasswd2=$(dialog --insecure --passwordbox "Reenter new password for utest." 10 40 3>&1 1>&2 2>&3)

						case $? in
							0)
								if [ "$newPasswd" == "$newPasswd2" ]
								then 
									if [ "$newPasswd" == "" ]
									then
										dialog --msgbox "No password was entered.\n\nPlease try it again." 10 40

									else
										echo -e "$newPasswd\n$newPasswd" | passwd utest
										counterPassword_1=1
										counterPassword=1
										dialog --msgbox "Password successfully updated for utest." 10 40
									fi
										
								else
									dialog --msgbox "Passwords do not match.\n\nPlease try it again." 10 40
								fi
								;;
							1)
								counterPassword_1=1
								;;
							255)
								;;
						esac
						;;
					1)
						counterPassword_1=1
						;;
					255)
						counterPassword_1=1
						;;
				esac
			done
			;;
		1)
			dialog --msgbox "Password was not changed for utest." 10 40
			counterPassword=1
			;;
		255)
			dialog --msgbox "Password was not changed for utest." 10 40
			counterPassword=1
			;;
	esac
done


#############################
# Token Licensing
#############################

/root/setup/tokenLicensing.sh

#############################
# Reboot
#############################

touch ~/.setupran

/usr/bin/dialog --title "Reboot" --clear \
		--yesno "Reboot now to have everything take effect?" 10 40

case $? in
	0)
		shutdown -r now;;
	1);;
	255);;
esac
